@@ -1,12 +1,13 @@
 package Complete::Fish::Gen::FromGetoptLong;
 
-our $DATE = '2014-11-29'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+#use Complete;
 use Getopt::Long::Util qw(parse_getopt_long_opt_spec);
 use String::ShellQuote;
 
@@ -77,7 +78,7 @@ sub gen_fish_complete_from_getopt_long_spec {
 }
 
 1;
-# ABSTRACT: Generate tab completion commands for the fish shell
+# ABSTRACT: From Getopt::Long spec, generate tab completion commands for the fish shell
 
 __END__
 
@@ -87,14 +88,20 @@ __END__
 
 =head1 NAME
 
-Complete::Fish::Gen::FromGetoptLong - Generate tab completion commands for the fish shell
+Complete::Fish::Gen::FromGetoptLong - From Getopt::Long spec, generate tab completion commands for the fish shell
 
 =head1 VERSION
 
-This document describes version 0.01 of Complete::Fish::Gen::FromGetoptLong (from Perl distribution Complete-Fish-Gen-FromGetoptLong), released on 2014-11-29.
+This document describes version 0.02 of Complete::Fish::Gen::FromGetoptLong (from Perl distribution Complete-Fish-Gen-FromGetoptLong), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
+=head1 SEE ALSO
+
+This module is used by L<Getopt::Long::Complete>.
+
+L<Perinci::Sub::To::FishComplete>
+
 =head1 FUNCTIONS
 
 
@@ -116,8 +123,6 @@ Getopt::Long options specification.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -127,13 +132,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-A script that can be fed to the fish shell (str)
-
-=head1 SEE ALSO
-
-This module is used by L<Getopt::Long::Complete>.
-
-L<Perinci::Sub::To::FishComplete>
+Return value: A script that can be fed to the fish shell (str)
 
 =head1 HOMEPAGE
 
@@ -157,7 +156,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
